##
##  docker.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg 27.5.0
%define       V_snap 20250114

#   package information
Name:         docker
Summary:      Docker Command-Line Interface
URL:          https://www.docker.com/community-edition
Vendor:       Docker Inc.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Filesystem
License:      Apache
Version:      %{V_opkg}.%{V_snap}
Release:      20250114

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/docker/docker-%{V_snap}.tar.xz
Patch0:       docker.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go, md2man
PreReq:       OpenPKG, openpkg >= 20160101

%description
    This package contains the Docker Client Command-Line Interface (CLI)
    only. It has to remotely connect to the Docker Daemon of an existing
    Docker installation.

%track
    prog docker = {
        version   = %{V_opkg}
        url       = https://github.com/docker/cli/tags
        regex     = v(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n docker
    %patch -p0
    %{l_shtool} subst %{l_value -s -a} \
        src/github.com/docker/cli/cli-plugins/manager/manager_unix.go

%build
    #   build program
    export GOPATH=`pwd`
    cd $GOPATH/src/github.com/docker/cli
    cp  cli/config/credentials/default_store_linux.go \
        cli/config/credentials/default_store_freebsd.go
    date=`date "+%%a %%b %%d %%H:%%M:%%S %%Y"`
    export GO111MODULE=auto
    go build \
        -v \
        -ldflags "-X 'github.com/docker/cli/cli/version.GitCommit=000000' \
            -X 'github.com/docker/cli/cli/version.BuildTime=$date' \
            -X 'github.com/docker/cli/cli/version.Version=%{V_opkg}'" \
        -o docker \
        ./cmd/docker

    #   build manpages
    (   cd $GOPATH/src/github.com/docker/cli
        %{l_shtool} subst -e 's;/tmp/go-md2man;md2man;g' scripts/docs/generate-man.sh
        export DISABLE_WARN_OUTSIDE_CONTAINER=1
        %{l_make} %{l_mflags} manpages
        rm -f /tmp/gen-manpages
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib/docker/cli-plugins \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/docker/cli/docker \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   install manpages
    %{l_shtool} install -c -m 644 \
        src/github.com/docker/cli/man/man1/*.1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_shtool} install -c -m 644 \
        src/github.com/docker/cli/man/man5/*.5 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

